pub struct SingleProcessDatacard<'a> { /* private fields */ }Expand description
A Combine datacard with one process column per channel.
Implementations
Sourceimpl<'a> SingleProcessDatacard<'a>
impl<'a> SingleProcessDatacard<'a>
Sourcepub fn new(process: impl Into<String>) -> Self
pub fn new(process: impl Into<String>) -> Self
Create a single-process datacard. The default process index is 0.
Sourcepub fn with_process_index(self, process_index: i32) -> Self
pub fn with_process_index(self, process_index: i32) -> Self
Set the Combine process index used in the numeric process row.
Sourcepub fn with_channel(self, channel: Channel<'a>) -> Self
pub fn with_channel(self, channel: Channel<'a>) -> Self
Add one channel/bin. In this slice each channel has exactly one process.
Sourcepub fn with_flat_weight_systematic(
self,
systematic: FlatWeightSystematic,
) -> Self
pub fn with_flat_weight_systematic( self, systematic: FlatWeightSystematic, ) -> Self
Add a flat normalization-only weight systematic emitted as lnN.
pub fn process(&self) -> &str
pub fn channels(&self) -> &[Channel<'a>]
pub fn flat_weight_systematics(&self) -> &[FlatWeightSystematic]
Sourcepub fn write(&self, output_dir: &Path) -> Result<DatacardOutput>
pub fn write(&self, output_dir: &Path) -> Result<DatacardOutput>
Write datacard.txt and shapes.root into output_dir.